@@ -1,15 +1,19 @@
+import os
 import pdb
 
+from runpy import run_path
 from typing import List, Union
 
 from mitmproxy.http import Request as MitmproxyRequest
 
 from stoobly_agent.app.settings.constants import firewall_action, intercept_mode
-from stoobly_agent.app.settings.filter_rule import FilterRule
+from stoobly_agent.app.settings.rewrite_rule import RewriteRule
 from stoobly_agent.app.settings.firewall_rule import FirewallRule
 from stoobly_agent.app.settings import Settings
-from stoobly_agent.config.constants import custom_headers, mode, request_origin
+from stoobly_agent.app.settings.types import IgnoreRule, RedactRule
+from stoobly_agent.config.constants import custom_headers, mode, request_origin, test_filter
 from stoobly_agent.lib.api.keys.project_key import InvalidProjectKey, ProjectKey
+from stoobly_agent.lib.logger import Logger
 
 class InterceptSettings:
 
@@ -32,14 +36,22 @@ class InterceptSettings:
     # If no valid project key is provided, use default settings,
     # Otherwise, set settings for the project
     self.__data_rules = self.__settings.proxy.data.data_rules(project_id)
-    self.__filter_rules = self.__settings.proxy.filter.filter_rules(project_id)
+    self.__rewrite_rules = self.__settings.proxy.rewrite.rewrite_rules(project_id)
     self.__firewall_rules = self.__settings.proxy.firewall.firewall_rules(project_id)
     self.__intercept_settings = self.__settings.proxy.intercept 
 
+    self.__lifecycle_hooks = None
+    self.__initialize_lifecycle_hooks()
+
   @property
   def settings(self):
     return self.__settings
 
+  @property
+  def alias_resolve_strategy(self):
+    if self.__headers and custom_headers.ALIAS_RESOLVE_STRATEGY in self.__headers:
+      return self.__headers[custom_headers.ALIAS_RESOLVE_STRATEGY]
+
   @property
   def active(self):
     if self.__intercept_settings.active:
@@ -47,10 +59,18 @@ class InterceptSettings:
     
     return self.__headers and custom_headers.PROXY_MODE in self.__headers
 
+  @property
+  def lifecycle_hooks_script_path(self):
+    if self.__headers and custom_headers.LIFECYCLE_HOOKS_SCRIPT_PATH in self.__headers:
+      return self.__headers[custom_headers.LIFECYCLE_HOOKS_SCRIPT_PATH]
+
+  @property
+  def lifecycle_hooks(self):
+    return self.__lifecycle_hooks or {}
+
   @property
   def mode(self):
     if self.__headers:
-      '''
       access_control_header = self.__headers.get('Access-Control-Request-Headers')
       do_proxy_header = custom_headers.DO_PROXY
 
@@ -59,7 +79,6 @@ class InterceptSettings:
 
       if do_proxy_header in self.__headers:
           return mode.NONE
-      '''
 
       if custom_headers.PROXY_MODE in self.__headers:
           return self.__headers[custom_headers.PROXY_MODE]
@@ -73,6 +92,13 @@ class InterceptSettings:
 
     return self.__settings.proxy.intercept.project_key
 
+  @property
+  def response_mode(self):
+    if custom_headers.RESPONSE_PROXY_MODE in self.__headers:
+      return self.__headers[custom_headers.RESPONSE_PROXY_MODE]
+
+    return self.mode
+
   @property
   def scenario_key(self):
     if self.__headers and custom_headers.SCENARIO_KEY in self.__headers:
@@ -116,16 +142,16 @@ class InterceptSettings:
     return list(filter(lambda rule: rule.action == firewall_action.INCLUDE, self.__firewall_rules))
 
   @property
-  def redact_rules(self) -> List[FilterRule]:
-    return self.__select_filter_rules()
+  def redact_rules(self) -> List[RedactRule]:
+    return self.__select_rewrite_rules(mode.RECORD)
 
   @property
-  def ignore_rules(self) -> List[FilterRule]:
-    return self.__select_filter_rules()
+  def ignore_rules(self) -> List[IgnoreRule]:
+    return []
 
   @property
-  def rewrite_rules(self) -> List[FilterRule]:
-    return self.__select_filter_rules()
+  def rewrite_rules(self) -> List[RewriteRule]:
+    return self.__select_rewrite_rules()
 
   @property
   def upstream_url(self):
@@ -138,6 +164,13 @@ class InterceptSettings:
 
     if self.__request:
       return f"{self.__request.scheme}://{self.__request.host}:{self.__request.port}"
+
+  @property
+  def test_filter(self):
+    if self.__headers and custom_headers.TEST_FILTER in self.__headers:
+      return self.__headers[custom_headers.TEST_FILTER]
+
+    return test_filter.ALL
   
   @property
   def test_strategy(self):
@@ -153,31 +186,47 @@ class InterceptSettings:
 
     return request_origin.WEB
 
-  def __select_filter_rules(self):
+  def __select_rewrite_rules(self, mode = None):
     rules = []
 
     # Filter only parameters matching active intercept mode
-    for filter_rule in self.__filter_rules:
-      parameter_rules = self.__select_parameter_rules(filter_rule)
+    for rewrite_rule in self.__rewrite_rules:
+      parameter_rules = self.__select_parameter_rules(rewrite_rule)
 
       # If no parameters rules were found, then this filter rule is not applied
       if len(parameter_rules) == 0:
         continue
 
-      # Build a new FilterRule object contain only parameter rules matching intercept mode
-      filter_rule = FilterRule({
-        'methods': filter_rule.methods,
-        'pattern': filter_rule.pattern,
+      # Build a new RewriteRule object contain only parameter rules matching intercept mode
+      rewrite_rule = RewriteRule({
+        'methods': rewrite_rule.methods,
+        'pattern': rewrite_rule.pattern,
         'parameters_rules': [], # Has to be dict form, manually set it
       })
-      filter_rule.parameter_rules = parameter_rules
+      rewrite_rule.parameter_rules = parameter_rules
 
-      rules.append(filter_rule)
+      rules.append(rewrite_rule)
 
     return rules
 
-  def __select_parameter_rules(self, filter_rule: FilterRule):
+  def __select_parameter_rules(self, rewrite_rule: RewriteRule, mode = None):
+    mode = mode or self.mode
     return list(filter(
-      lambda parameter: self.mode in parameter.modes and parameter.name, 
-      filter_rule.parameter_rules or []
-    ))
\ No newline at end of file
+      lambda parameter: mode in parameter.modes and parameter.name, 
+      rewrite_rule.parameter_rules or []
+    ))
+
+  def __initialize_lifecycle_hooks(self):
+    script_path = self.lifecycle_hooks_script_path
+
+    if not script_path:
+        return
+
+    if not os.path.exists(script_path):
+        return Logger.instance().error(f"Lifecycle hooks script {script_path} does not exist")
+
+    try:
+        self.__lifecycle_hooks = run_path(script_path)
+    except Exception as e:
+        return Logger.instance().error(e)
+    
\ No newline at end of file
